(error "git-blame.el no longer ships with git. It's recommended
to replace its use with Emacs's own vc-annotate. See
contrib/emacs/README in git's
sources (https://github.com/git/git/blob/master/contrib/emacs/README)
for more info on suggested alternatives and for why this
happened.")
